.. -*- coding: utf-8 -*-

Une fois que vous avez lu le `tutoriel RQL`_ et que vous connaissez le `schéma`_
de l'application, vous êtes prêt à définir vos propres vues. Tapez simplement
dans le champ de recherche la requête qui vous permet de récupérer les données
qui vous intéressent. Si la vue appliquée par défaut ne correspond pas à vos
besoins, sélectionnez en une autre dans la boîte des vues possibles (celle-ci
n'est pas affichée par défaut, vous pouvez l'activer dans vos `préférences
utilisateur`_). Une fois que vous êtes satisfait, ajoutez un `signet`_ si vous
voulez réutiliser votre vue plus tard.

.. _`tutoriel RQL`: doc/tut_rql
.. _`schéma`: schema
.. _`préférences utilisateur`: myprefs
.. _`signet`: doc/bookmarks


Ci-dessous quelques exemples de ce que l'on peut faire...

.. winclude:: custom_view_last_update
.. winclude:: custom_view_rss
